"""
Library for extracting and re-packing assets from Spelunky 2.

The vast majority of the work behind extracting these assets comes
from the work of SciresM.

https://gist.github.com/SciresM/d97e21a02d4a4cdc11b2b97cf43efea3

Additional a lot of clean up and expansion of that work came from
Cloppershy

https://gist.github.com/Cloppershy/a32b9139f3d222b5ff5b8b23ffac1aac

Both of these contributions were crucial to this library.

Cloppershy was also instrumental in providing the implementation for
repacking, as seen here:

https://gist.github.com/Cloppershy/046846e593362a2a7284c28f39899eae


Additionally, `iojonmbnmb#8149 ` provided the updated hashing code when
it was broken in 1.13.0
"""

